==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Modify/Explode/ts/Explode_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja_JP">
<context>
    <name>Dialog</name>
    <message>
        <location filename="../ExplodeDialog.ui" line="+14"/>
        <source>Dialog</source>
        <translation>ダイアログ</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Arcs and Circles</source>
        <translation>弧と円</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into line segments (fixed length)</source>
        <translation>線分情報（長さ固定）</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>into line segments (fixed angle)</source>
        <translation>線分情報（角度固定）</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Ellipses</source>
        <translation>弧</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into polyline with arc segments</source>
        <translation>弧のポリライン情報</translation>
    </message>
    <message>
        <location line="+5"/>
        <location line="+16"/>
        <source>into polyline with line segments</source>
        <translation>線分のポリライン情報</translation>
    </message>
    <message>
        <location line="-8"/>
        <source>Splines</source>
        <translation>スプライン</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Dimensions</source>
        <translation>寸法</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into lines, solids and texts</source>
        <translation>線分、ソリッド及びテキスト情報</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Hatches</source>
        <translation>ハッチング</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into lines</source>
        <translation>線分情報</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Blocks</source>
        <translation>ブロック</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into entities</source>
        <translation>エンティティ情報</translation>
    </message>
</context>
<context>
    <name>Explode</name>
    <message>
        <location filename="../Explode.js" line="+30"/>
        <source>Modify</source>
        <translation>修正</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Explode</source>
        <translation>分解</translation>
    </message>
    <message>
        <location filename="../ExplodeInit.js" line="+2"/>
        <source>&amp;Explode</source>
        <translation>&amp;E 分解</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+133"/>
        <source>Spline segments:</source>
        <translation>スプラインセグメント:</translation>
    </message>
    <message>
        <location line="-7"/>
        <source>Ellipse segments (per full ellipse):</source>
        <translation>弧セグメント（楕円あたり）:</translation>
    </message>
    <message>
        <location line="-7"/>
        <source>Spline approximation tolerance:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Modify/Explode/ts/Explode_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>Dialog</name>
    <message>
        <location filename="../ExplodeDialog.ui" line="+14"/>
        <source>Dialog</source>
        <translation>ダイアログ</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Arcs and Circles</source>
        <translation>弧と円</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into line segments (fixed length)</source>
        <translation>線分情報（長さ固定）</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>into line segments (fixed angle)</source>
        <translation>線分情報（角度固定）</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Ellipses</source>
        <translation>弧</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into polyline with arc segments</source>
        <translation>弧のポリライン情報</translation>
    </message>
    <message>
        <location line="+5"/>
        <location line="+16"/>
        <source>into polyline with line segments</source>
        <translation>線分のポリライン情報</translation>
    </message>
    <message>
        <location line="-8"/>
        <source>Splines</source>
        <translation>スプライン</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Dimensions</source>
        <translation>寸法</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into lines, solids and texts</source>
        <translation>線分、ソリッド及びテキスト情報</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Hatches</source>
        <translation>ハッチング</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into lines</source>
        <translation>線分情報</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Blocks</source>
        <translation>ブロック</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into entities</source>
        <translation>エンティティ情報</translation>
    </message>
</context>
<context>
    <name>Explode</name>
    <message>
        <location filename="../Explode.js" line="+30"/>
        <source>Modify</source>
        <translation>修正</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Explode</source>
        <translation>分解</translation>
    </message>
    <message>
        <location filename="../ExplodeInit.js" line="+2"/>
        <source>&amp;Explode</source>
        <translation>&amp;E 分解</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+197"/>
        <source>Explode text glyphs to polylines</source>
        <translation>テキストのグリフをポリラインに分解</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Spline segments:</source>
        <translation>スプラインセグメント:</translation>
    </message>
    <message>
        <location line="-27"/>
        <source>Ellipse segments (per full ellipse):</source>
        <translation>弧セグメント（楕円あたり）:</translation>
    </message>
    <message>
        <location line="-7"/>
        <source>Explode splines to polylines with line segments</source>
        <translation>スプラインを線分セグメントのポリラインに分解</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Explode multiline texts into multiple simple text blocks</source>
        <translation>マルチラインテキストを複数の1行テキストに分解する</translation>
    </message>
    <message>
        <location line="-31"/>
        <source>Spline approximation tolerance:</source>
        <translation>スプライン近似公差:</translation>
    </message>
</context>
</TS>
